@@ -1,13 +1,13 @@
 use std::io::Read;
 
-use git_object::{mutable, Kind};
+use git_object::Kind;
 
 use crate::store::{compound, loose};
 
 impl crate::write::Write for compound::Store {
     type Error = loose::write::Error;
 
-    fn write(&self, object: &mutable::Object, hash: git_hash::Kind) -> Result<git_hash::ObjectId, Self::Error> {
+    fn write(&self, object: impl git_object::WriteTo, hash: git_hash::Kind) -> Result<git_hash::ObjectId, Self::Error> {
         self.loose.write(object, hash)
     }
 
