@@ -5,7 +5,7 @@ use git_pack::{data, loose::object::header};
 
 use crate::store::loose::{sha1_path, Store, HEADER_READ_UNCOMPRESSED_BYTES};
 
-/// Returned by [`Store::find()`]
+/// Returned by [`Store::try_find()`]
 #[derive(thiserror::Error, Debug)]
 #[allow(missing_docs)]
 pub enum Error {
@@ -38,7 +38,7 @@ impl Store {
     ///
     /// Returns `Err` if there was an error locating or reading the object. Returns `Ok<None>` if
     /// there was no such object.
-    pub fn find<'a>(
+    pub fn try_find<'a>(
         &self,
         id: impl AsRef<git_hash::oid>,
         out: &'a mut Vec<u8>,
