@@ -1,6 +1,6 @@
 use std::io;
 
-use git_object::mutable;
+use git_object::WriteTo;
 
 /// Describe the capability to write git objects into an object store.
 pub trait Write {
@@ -9,9 +9,9 @@ pub trait Write {
     /// _Note_ the default implementations require the `From<io::Error>` bound.
     type Error: std::error::Error + From<io::Error>;
 
-    /// Write [`object`][mutable::Object] using the given kind of [`hash`][git_hash::Kind] into the database,
+    /// Write [`object`][Object] using the given kind of [`hash`][git_hash::Kind] into the database,
     /// returning id to reference it in subsequent reads.
-    fn write(&self, object: &mutable::Object, hash: git_hash::Kind) -> Result<git_hash::ObjectId, Self::Error> {
+    fn write(&self, object: impl WriteTo, hash: git_hash::Kind) -> Result<git_hash::ObjectId, Self::Error> {
         let mut buf = Vec::with_capacity(2048);
         object.write_to(&mut buf)?;
         self.write_stream(object.kind(), buf.len() as u64, buf.as_slice(), hash)
